"""
This package contains the :ref:`directgui` system, a set of classes
responsible for drawing graphical widgets to the 2-D scene graph.

It is based on the lower-level PGui system, which is implemented in
C++.

For convenience, all of the DirectGui widgets may be imported from a
single module as follows::

   from direct.gui.DirectGui import *
"""
